dSFMT-jump: dSFMT-calc-jump.hpp File Reference

dSFMT-jump 0.1

- Main Page
- Namespaces
- Data Structures
- Files

- File List
- Globals

Namespaces | Functions
dSFMT-calc-jump.hpp File Reference

functions for calculating jump polynomial. More...

`#include <iostream>`
`#include <iomanip>`
`#include <sstream>`
`#include <NTL/GF2X.h>`

Go to the source code of this file.

## Namespaces
namespace | dsfmt
## Functions
static void | dsfmt::polytostring (std::string &x, NTL::GF2X &polynomial)
| converts polynomial to string for convenient use in C language.
static void | dsfmt::stringtopoly (NTL::GF2X &poly, std::string &str)
| converts string to polynomial
static void | dsfmt::calc_jump (std::string &jump_str, NTL::ZZ &step, NTL::GF2X &characteristic)
| calculate the jump polynomial.

## Detailed Description

functions for calculating jump polynomial.

Author:
  Mutsuo Saito (Hiroshima University)
  Makoto Matsumoto (The University of Tokyo)

Copyright (C) 2012 Mutsuo Saito, Makoto Matsumoto, Hiroshima University and The University of Tokyo. All rights reserved.

The 3-clause BSD License is applied to this software, see LICENSE.txt